require 'spec_helper'
require 'riedi/server'

describe Riedi::Server do
  before do
    @storage = Riedi::Storage.new
    @storage.flushall
    @storage.set("key", "value")
  end

  def app
    Riedi::Server
  end

  it "GET /status" do
    get "/status" do
      last_response.status.should be(200)
      last_response.body.should eq("OK")
    end
  end

  it "GET /keys" do
    get "/keys" do
      last_response.status.should be(200)
      last_response.body.should eq("[\"key\"]")
    end
  end

  it "POST /store/key" do
    post "/store/key", "value=value" do
      last_response.status.should be(200)
      last_response.body.should eq("OK")
    end
  end

  it "GET /store/key" do
    get "/store/key" do
      last_response.status.should be(200)
      last_response.body.should eq("value")
    end
  end

  it "GET /store/missing" do
    get "/store/missing" do
      last_response.status.should be(404)
      last_response.body.should eq("")
    end
  end

  it "DELETE /store/key" do
    delete "/store/key" do
      last_response.status.should be(200)
      last_response.body.should eq("1")
    end
  end

  it "DELETE /store/missing" do
    delete "/store/missing" do
      last_response.status.should be(404)
      last_response.body.should eq("")
    end
  end
end
